@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Sequence, Union
 
-from botocore.response import StreamingBody
-
 from .literals import (
     AlarmTypeType,
     AnomalyDetectorStateValueType,
@@ -699,7 +697,7 @@ class GetMetricWidgetImageInputRequestTypeDef(
 GetMetricWidgetImageOutputTypeDef = TypedDict(
     "GetMetricWidgetImageOutputTypeDef",
     {
-        "MetricWidgetImage": StreamingBody,
+        "MetricWidgetImage": bytes,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
